EXPORTS
	??0CWSPolicy@@AAE@XZ @ 1 NONAME ; CWSPolicy::CWSPolicy(void)
	??1CExpiredPolicy@@UAE@XZ @ 2 NONAME ; CExpiredPolicy::~CExpiredPolicy(void)
	??1CSenWSPolicyManager@@UAE@XZ @ 3 NONAME ; CSenWSPolicyManager::~CSenWSPolicyManager(void)
	?AddPolicyConsumerL@CSenWSPolicyManager@@QAEHABVTDesC8@@0@Z @ 4 NONAME ; int CSenWSPolicyManager::AddPolicyConsumerL(class TDesC8 const &, class TDesC8 const &)
	?AddWsPolicyL@CSenWSPolicyManager@@QAEHPAVCSenWSDescription@@ABVTDesC8@@1AAH@Z @ 5 NONAME ; int CSenWSPolicyManager::AddWsPolicyL(class CSenWSDescription *, class TDesC8 const &, class TDesC8 const &, int &)
	?ConstructL@CWSPolicy@@AAEXXZ @ 6 NONAME ; void CWSPolicy::ConstructL(void)
	?Contents@CExpiredPolicy@@QAE?AVTPtrC8@@XZ @ 7 NONAME ; class TPtrC8 CExpiredPolicy::Contents(void)
	?Contract@CExpiredPolicy@@QAE?AVTPtrC8@@XZ @ 8 NONAME ; class TPtrC8 CExpiredPolicy::Contract(void)
	?Endpoint@CExpiredPolicy@@QAE?AVTPtrC8@@XZ @ 9 NONAME ; class TPtrC8 CExpiredPolicy::Endpoint(void)
	?ExpiredPoliciesL@CSenWSPolicyManager@@QAEHAAV?$RPointerArray@VCExpiredPolicy@@@@AAH@Z @ 10 NONAME ; int CSenWSPolicyManager::ExpiredPoliciesL(class RPointerArray<class CExpiredPolicy> &, int &)
	?IntersectPolicyL@CWSPolicy@@QAEPAV1@PAV1@@Z @ 11 NONAME ; class CWSPolicy * CWSPolicy::IntersectPolicyL(class CWSPolicy *)
	?IsExpiredPolicyL@CWSPolicy@@QAEHXZ @ 12 NONAME ; int CWSPolicy::IsExpiredPolicyL(void)
	?IsExpiredPolicyL@CWSPolicyUtils@@SAHPAVCSenElement@@@Z @ 13 NONAME ; int CWSPolicyUtils::IsExpiredPolicyL(class CSenElement *)
	?LookupPolicy@CPolicyRegistry@@QAEPAVCSenElement@@ABVTPtrC8@@@Z @ 14 NONAME ; class CSenElement * CPolicyRegistry::LookupPolicy(class TPtrC8 const &)
	?LookupPolicyByNameL@CPolicyRegistry@@QAEPAVCSenElement@@ABVTPtrC8@@@Z @ 15 NONAME ; class CSenElement * CPolicyRegistry::LookupPolicyByNameL(class TPtrC8 const &)
	?MergePolicyL@CWSPolicy@@QAEPAV1@PAV1@@Z @ 16 NONAME ; class CWSPolicy * CWSPolicy::MergePolicyL(class CWSPolicy *)
	?NewL@CExpiredPolicy@@SAPAV1@ABVTDesC8@@000@Z @ 17 NONAME ; class CExpiredPolicy * CExpiredPolicy::NewL(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?NewL@CPolicyRegistry@@SAPAV1@XZ @ 18 NONAME ; class CPolicyRegistry * CPolicyRegistry::NewL(void)
	?NewL@CSenWSPolicyManager@@SAPAV1@AAVMSenCoreServiceManager@@@Z @ 19 NONAME ; class CSenWSPolicyManager * CSenWSPolicyManager::NewL(class MSenCoreServiceManager &)
	?NewL@CWSPolicy@@SAPAV1@AAVTDesC8@@0@Z @ 20 NONAME ; class CWSPolicy * CWSPolicy::NewL(class TDesC8 &, class TDesC8 &)
	?NewL@CWSPolicy@@SAPAV1@PAVCSenElement@@@Z @ 21 NONAME ; class CWSPolicy * CWSPolicy::NewL(class CSenElement *)
	?NewL@CWSPolicy@@SAPAV1@XZ @ 22 NONAME ; class CWSPolicy * CWSPolicy::NewL(void)
	?NewLC@CExpiredPolicy@@SAPAV1@ABVTDesC8@@000@Z @ 23 NONAME ; class CExpiredPolicy * CExpiredPolicy::NewLC(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?NewLC@CPolicyRegistry@@SAPAV1@XZ @ 24 NONAME ; class CPolicyRegistry * CPolicyRegistry::NewLC(void)
	?NewLC@CSenWSPolicyManager@@SAPAV1@AAVMSenCoreServiceManager@@@Z @ 25 NONAME ; class CSenWSPolicyManager * CSenWSPolicyManager::NewLC(class MSenCoreServiceManager &)
	?NewLC@CWSPolicy@@SAPAV1@AAVTDesC8@@0@Z @ 26 NONAME ; class CWSPolicy * CWSPolicy::NewLC(class TDesC8 &, class TDesC8 &)
	?NewLC@CWSPolicy@@SAPAV1@PAVCSenElement@@@Z @ 27 NONAME ; class CWSPolicy * CWSPolicy::NewLC(class CSenElement *)
	?NewLC@CWSPolicy@@SAPAV1@XZ @ 28 NONAME ; class CWSPolicy * CWSPolicy::NewLC(void)
	?NonNormalizedPolicyL@CWSPolicy@@QAEPAVCSenElement@@XZ @ 29 NONAME ; class CSenElement * CWSPolicy::NonNormalizedPolicyL(void)
	?NormalizePolicyL@CWSPolicy@@QAEHPAVCPolicyRegistry@@@Z @ 30 NONAME ; int CWSPolicy::NormalizePolicyL(class CPolicyRegistry *)
	?Normalized@CWSPolicy@@QAEHXZ @ 31 NONAME ; int CWSPolicy::Normalized(void)
	?Parent@CPolicyRegistry@@QAEPAV1@XZ @ 32 NONAME ; class CPolicyRegistry * CPolicyRegistry::Parent(void)
	?PolicyAsXmlL@CWSPolicy@@QAEPAVHBufC8@@XZ @ 33 NONAME ; class HBufC8 * CWSPolicy::PolicyAsXmlL(void)
	?PolicyIdL@CWSPolicyUtils@@SA?AVTPtrC8@@PAVCSenElement@@@Z @ 34 NONAME ; class TPtrC8 CWSPolicyUtils::PolicyIdL(class CSenElement *)
	?PolicyL@CWSPolicy@@QAEPAVCSenElement@@XZ @ 35 NONAME ; class CSenElement * CWSPolicy::PolicyL(void)
	?PolicyNameL@CWSPolicyUtils@@SA?AVTPtrC8@@PAVCSenElement@@@Z @ 36 NONAME ; class TPtrC8 CWSPolicyUtils::PolicyNameL(class CSenElement *)
	?PolicyUriL@CWSPolicyUtils@@SA?AVTPtrC8@@PAVCSenElement@@@Z @ 37 NONAME ; class TPtrC8 CWSPolicyUtils::PolicyUriL(class CSenElement *)
	?PopulateRegistryL@CPolicyRegistry@@QAEXPAVCSenElement@@@Z @ 38 NONAME ; void CPolicyRegistry::PopulateRegistryL(class CSenElement *)
	?RegisterPolicy@CPolicyRegistry@@QAEXAAVTDesC8@@PAVCSenElement@@@Z @ 39 NONAME ; void CPolicyRegistry::RegisterPolicy(class TDesC8 &, class CSenElement *)
	?RegisterWsPolicyL@CSenWSPolicyManager@@QAEHPAVCSenWSDescription@@AAH@Z @ 40 NONAME ; int CSenWSPolicyManager::RegisterWsPolicyL(class CSenWSDescription *, int &)
	?RemovePolicyConsumerL@CSenWSPolicyManager@@QAEHABVTDesC8@@0@Z @ 41 NONAME ; int CSenWSPolicyManager::RemovePolicyConsumerL(class TDesC8 const &, class TDesC8 const &)
	?RemoveWsPolicyL@CSenWSPolicyManager@@QAEHPAVCSenWSDescription@@ABVTDesC8@@AAH@Z @ 42 NONAME ; int CSenWSPolicyManager::RemoveWsPolicyL(class CSenWSDescription *, class TDesC8 const &, int &)
	?ResetRegistry@CPolicyRegistry@@QAEXXZ @ 43 NONAME ; void CPolicyRegistry::ResetRegistry(void)
	?SetContentsL@CExpiredPolicy@@QAEHABVTDesC8@@@Z @ 44 NONAME ; int CExpiredPolicy::SetContentsL(class TDesC8 const &)
	?SetParent@CPolicyRegistry@@QAEXPAV1@@Z @ 45 NONAME ; void CPolicyRegistry::SetParent(class CPolicyRegistry *)
	?SetPolicyL@CWSPolicy@@QAEHAAVTDesC8@@0@Z @ 46 NONAME ; int CWSPolicy::SetPolicyL(class TDesC8 &, class TDesC8 &)
	?UnRegisterWsPolicyL@CSenWSPolicyManager@@QAEHPAVCSenWSDescription@@AAH@Z @ 47 NONAME ; int CSenWSPolicyManager::UnRegisterWsPolicyL(class CSenWSDescription *, int &)
	?UnregisterPolicy@CPolicyRegistry@@QAEXABVTPtrC8@@@Z @ 48 NONAME ; void CPolicyRegistry::UnregisterPolicy(class TPtrC8 const &)
	?Uri@CExpiredPolicy@@QAE?AVTPtrC8@@XZ @ 49 NONAME ; class TPtrC8 CExpiredPolicy::Uri(void)
	?WsPolicyL@CSenWSPolicyManager@@QAEPAVCSenElement@@PAVCSenWSDescription@@ABVTDesC8@@AAH@Z @ 50 NONAME ; class CSenElement * CSenWSPolicyManager::WsPolicyL(class CSenWSDescription *, class TDesC8 const &, int &)
	?GetEffectiveOutputPolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@00@Z @ 51 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveOutputPolicyL(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?GetEffectiveServicePolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@@Z @ 52 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveServicePolicyL(class TDesC8 const &)
	?GetEffectiveOperationPolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@00@Z @ 53 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveOperationPolicyL(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?NewLC@CWsdlPolicyAttachment@@SAPAV1@ABVTDesC8@@@Z @ 54 NONAME ; class CWsdlPolicyAttachment * CWsdlPolicyAttachment::NewLC(class TDesC8 const &)
	?NewL@CWsdlPolicyAttachment@@SAPAV1@ABVTDesC8@@@Z @ 55 NONAME ; class CWsdlPolicyAttachment * CWsdlPolicyAttachment::NewL(class TDesC8 const &)
	?GetEffectiveInputPolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@00@Z @ 56 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveInputPolicyL(class TDesC8 const &, class TDesC8 const &, class TDesC8 const &)
	?GetEffectiveFaultPolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@0@Z @ 57 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveFaultPolicyL(class TDesC8 const &, class TDesC8 const &)
	?GetEffectiveEndpointPolicyL@CWsdlPolicyAttachment@@QAEPAVCSenElement@@ABVTDesC8@@0@Z @ 58 NONAME ; class CSenElement * CWsdlPolicyAttachment::GetEffectiveEndpointPolicyL(class TDesC8 const &, class TDesC8 const &)

